@@ -277,16 +277,48 @@ keyboard_setup (void)
 
 
 
-void
+int
 main (int argc, char **argv)
 {
+        GnomeClient *client;
+        int token, init_results;
+        char *init_argv[3] = {NULL, "--init-session-settings", NULL};
+        
+        init_argv[0] = argv[0];
 
         bindtextdomain (PACKAGE, GNOMELOCALEDIR);
         textdomain (PACKAGE);
 
-        gnome_capplet_init ("keyboard-properties", VERSION, argc,
-                            argv, NULL, 0, NULL);
+        init_results = gnome_capplet_init ("keyboard-properties",
+                                           VERSION, argc, argv, NULL, 0, NULL);
 
+        client = gnome_master_client();
+
+        if(client) {
+                gnome_client_set_restart_command(client, 2, init_argv);
+                gnome_client_set_restart_style(client, GNOME_RESTART_ANYWAY);
+                gnome_client_flush(client);
+        }
+
+        switch(init_results) {
+        case -1:
+                return 1;
+        case 1:
+                if(client && gnome_client_get_previous_id(client)) {
+                        token = gnome_startup_acquire_token("GNOME_KEYBOARD_PROPERTIES",
+                                                            gnome_client_get_id(client));
+                } else
+                        token = 1;
+
+                if(token) {
+                        keyboard_read();
+                        keyboard_apply();
+                }
+
+                return 0;
+                break;
+        default: break;
+        }
         keyboard_read ();
         keyboard_setup();
         capplet_gtk_main ();
