@@ -144,7 +144,10 @@ void
 server_state_changed(PortableServer_Servant servant, CORBA_long id, CORBA_boolean undoable, CORBA_Environment * ev)
 {
         node_data *nd = find_node_by_id (id);
-        GtkStyle *style;
+        GdkColor col;
+        col.red = 56000;
+        col.green = 0;
+        col.blue = 0;
         if (nd == NULL){
                 g_warning ("couldn't find node %d\n",id);
                 g_warning ("this capplet will not function correctly...\n");
@@ -155,7 +158,6 @@ server_state_changed(PortableServer_Servant servant, CORBA_long id, CORBA_boolea
         if (undoable)
                 gtk_widget_set_sensitive (nd->revert_button, TRUE);
         gtk_widget_set_sensitive (nd->ok_button, TRUE);
-
-        style = gtk_widget_get_style (nd->label);
         
+        gtk_ctree_node_set_foreground (nd->ctree, nd->node, &col);
 }
