@@ -10,17 +10,33 @@
 #include "tree.h"
 #include "corba-glue.h"
 GtkWidget *main_window;
-GtkWidget *status_bar;
 GtkWidget *exit_dialog;
 GtkWidget *hpane;
 GtkWidget *container;
 GtkWidget *notebook = NULL;
 GtkWidget *splash_screen;
+GnomeAppBar *status_bar;
 gchar *init_cap = NULL;
+/* Temporary hack to make an RPM.  If anyone ever sees this, please, blow it away */
+#ifndef GNOMEUIINFO_MENU_EXIT_ITEM
+#define GNOMEUIINFO_MENU_EXIT_ITEM(cb, data)                                \
+        { GNOME_APP_UI_ITEM, N_("E_xit"), N_("Exit the program"),           \
+          cb, (gpointer)(data), NULL, GNOME_APP_PIXMAP_STOCK,               \
+	  GNOME_STOCK_MENU_EXIT, GNOME_KEY_NAME_EXIT, GNOME_KEY_MOD_EXIT,   \
+	    NULL }
+
+#define GNOMEUIINFO_MENU_ABOUT_ITEM(cb, data)                               \
+        { GNOME_APP_UI_ITEM, N_("_About..."),                               \
+          N_("About this application"), cb, (gpointer)(data),           \
+	  NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,             \
+          0,  (GdkModifierType) 0, NULL }
+#define GNOMEUIINFO_MENU_HELP_TREE(tree) \
+	{ GNOME_APP_UI_SUBTREE, N_("_Help"), NULL, tree, NULL, NULL, \
+		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL }
+#endif
 
 static GnomeUIInfo mainMenu[] = {
         GNOMEUIINFO_MENU_EXIT_ITEM(exit_callback, NULL), 
-
         GNOMEUIINFO_END
 };
 static GnomeUIInfo helpMenu[] = {
@@ -31,8 +47,7 @@ static GnomeUIInfo helpMenu[] = {
         GNOMEUIINFO_END
 };
 static GnomeUIInfo parentMenu[] = {
-        {GNOME_APP_UI_SUBTREE, N_("_Program"), NULL, mainMenu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+        GNOMEUIINFO_MENU_FILE_TREE(mainMenu),
 
         GNOMEUIINFO_MENU_HELP_TREE(helpMenu),
 
@@ -128,6 +143,13 @@ create_window ()
 	gnome_app_create_menus (GNOME_APP (retval), parentMenu);
         exit_dialog = NULL;
 
+        /* Create the status bar */
+        status_bar = GNOME_APPBAR(gnome_appbar_new(FALSE, TRUE,
+                                               GNOME_PREFERENCES_USER));
+	gnome_app_set_statusbar(GNOME_APP(retval), GTK_WIDGET(status_bar));
+
+	gnome_app_install_menu_hints(GNOME_APP (retval), parentMenu);
+
         /* create the components */
         vbox = gtk_vbox_new (FALSE,0);
         hpane = gtk_hpaned_new();
@@ -144,14 +166,12 @@ create_window ()
         splash_screen = gtk_drawing_area_new ();
         /*gdk_imlib_load_file_to_pixmap ("splash.png", &temp_splash, NULL);*/
         gtk_widget_set_usize (splash_screen, 300, 275);
-        status_bar = gtk_statusbar_new();
 
         /* we put it all together... */
         gtk_container_add (GTK_CONTAINER (sw), tree);
         gtk_paned_add1 (GTK_PANED (hpane), sw);
         gtk_paned_add2 (GTK_PANED (hpane), container); 
         gtk_container_add (GTK_CONTAINER (container), splash_screen);
-        gtk_box_pack_end (GTK_BOX (vbox), status_bar, FALSE, FALSE, 0);
         gtk_box_pack_end (GTK_BOX (vbox), hpane, TRUE, TRUE, 0);
         gnome_app_set_contents(GNOME_APP(retval), vbox);
         
